---
title: Defense system triggers
contributors: 
    - Avigail Stokar-Avihail
    - Alba Herrero del Valle
layout: article
---

# How anti-phage systems sense invading phages

Upon phage infection, the bacterial immune system senses a specific phage component or modification that the phage exerts on the cell to elicit the bacterial immune response. Understanding how bacteria sense phage infection is a fundamental question, which remains unanswered for the majority of recently discovered immune systems. There are dozens of cases in which the mechanism of immunity has been elucidated, but the phage trigger remains elusive. Understanding how antiphage systems are activated is key for a full understanding of bacterial immunity and for repurposing them as molecular tools as has been done for restriction enzymes and CRISPR-Cas. 

## Diversity

Various determinants of the phage can elicit bacterial immunity either in a direct or indirect manner. The most common and well-known prokaryotic anti-phage systems, restriction enzymes and CRISPR-Cas recognize and cleave phage DNA or RNA. More recently, a CBASS system has been found to directly bind to a structured phage RNA that triggers immune activation :ref{doi=10.1101/2023.03.07.531596}. In other cases, defense systems are activated by protein-coding phage genes. In some cases, the phage protein is directly sensed by the defense systems, as has been beautifully demonstrated for the Avs systems that directly bind either the phage terminase or portal protein :ref{doi=10.1126/science.abm4096}. In other cases, the phage protein can be sensed indirectly by the defense system, for example by detecting its activity in the cell. Such an indirect mechanism has been found for example in the case of some retron defense systems that are triggered by phage tampering with the RecBCD protein complex :ref{doi=10.1016/j.cell.2020.09.065,10.1016/j.cell.2023.02.029}. For comprehensive coverage of all recent phage detection mechanisms, the recent review by Huiting and Bondy-Denomy :ref{doi=10.1016/j.mib.2023.102325} is highly recommended. 

## Method of discovery:

The main method used to pinpoint phage components that trigger a specific defense system of interest has been through a simple classic genetics approach, whereby mutant phages that overcome the defense system are examined. Such mutants often occur spontaneously and can thus be selected for by simply picking phage plaques that are able to form on a lawn of bacteria expressing the defense system :ref{doi=10.1016/j.cell.2023.02.029,10.1016/j.mib.2023.102325}. The hypothesis is that the phage mutant escapes bacterial immunity due to a mutation in the component sensed by the system. Thus, sequencing these phage mutants and identification of the mutated locus is the first required step. To validate that the mutated phage component is indeed the actual trigger of the defense system, follow up experiments are required. For example, in some cases, expression of this phage component without any other phage genes is sufficient to elicit the activity of the bacterial immune system. This approach was used to identify Borvo activation by expression of the phage DNA polymerase, Dazbog activation by expression of a phage DNA methylase, retron activation by either phage SSB proteins :ref{doi=10.1016/j.cell.2023.02.029} or by proteins that inhibit the host RecBCD3, CapRel triggering by the phage Capsid protein :ref{doi=10.1038/s41586-022-05444-z} and many more :ref{doi=10.1016/j.mib.2023.102325}. Additional biochemical pulldown assays can be used to assess the binding of the defense system to the suspected phage trigger. 
One major caveat in the above approach is that in some cases mutant phages that escape the immune system cannot be isolated. This can occur for example if the defense system senses a general fold of a highly conserved and essential phage protein. In this case, a simple mutation in the protein will not suffice for the phage to escape detection. In such cases, an alternative approach can be used that does not rely on isolation of escape mutants. An overexpression library of all phage genes can be co-expressed with the defense system of interest and then assayed for immune activation. This approach was successfully applied for the identification of phage components that trigger diverse Avs systems :ref{doi=10.1126/science.abm4096}. 

## General concepts

Although much is still unknown regarding how bacterial immune systems sense phage infection, by combining the data observed so far, several general concepts in immune sensing are beginning to come to light. First, mechanistically diverse immune systems appear to have converged to sense common conserved phage components4.  These include the phage core replication machinery, host takeover machinery and structural components. Second, several studies have found cases in which defense occurs in a multi-layered fashion, whereby a second system is activated when the first one fails :ref{doi=10.1016/j.cell.2020.09.065,10.1016/j.chom.2022.02.018,10.1006/jmbi.1995.0343}. Research in upcoming years is expected to reveal additional guiding principles in the ways bacteria detect phages. 
