---
title: Anti Defense Systems
layout: article
toc: true
contributors:
    - Nathalie Bechon
---

# Anti-defense systems:

This article is non-exhaustive but introduces the topic of anti-defense systems. Several reviews mentioned here did a great in-depth characterization of the known anti-defense phage mechanism :ref{doi=10.3389/fmicb.2023.1211793,10.1016/j.jmb.2023.167974,10.1038/nrmicro3096}.
Several strategies allow phages to avoid bacterial defenses to successfully complete an infectious cycle. In particular, anti-defense proteins are bacteriophage proteins that specifically act against a bacterial defense system and thus allow bacteriophages to bypass the bacterial immune system. The most well-described category of anti-defense proteins is the anti-CRISPR proteins (Acr), which have been thoroughly reviewed previously :ref{doi=10.1038/nrmicro.2017.120,10.1016/j.jmb.2023.167974}. However, concomitant with the renewed interest of the field to identify new bacterial defense systems, many anti-defense proteins targeting diverse defense systems have recently been described. Using a non-exhaustive list of anti-defense proteins as examples, I will outline several general categories of anti-defense mechanisms. However, I will not focus on another common phage anti-defense strategy that relies on modifying their components, such as mutating the proteins that trigger the defense to escape or changing their DNA to avoid targeting by restriction-modification or CRISPR systems.

Anti-defense proteins are crucial to understand the evolutionary arms race between bacteria and their phages, as they likely drive the diversification of bacterial defense systems. Some defense systems even evolved to recognize anti-defense proteins as activators, providing multiple lines of defense during phage infection :ref{doi=10.1016/j.cell.2023.02.029}. Moreover, these proteins are also important in mediating phage/phage interactions. Indeed, anti-CRISPR proteins were suggested to be involved in phage/phage collaboration, in which a primo-infection by a phage carrying an anti-CRISPR protein is unsuccessful but leaves the bacteria immunosuppressed and therefore sensitive to a second phage infection :ref{doi=10.1016/j.jmb.2023.167974}. Considering the importance of overcoming bacterial defenses for phages, it is likely that a significant part of the phage proteins of unknown function currently found in phage-sequenced genomes act as anti-defense. Some anti-defense proteins were shown to colocalize in phage genomes, suggesting comparative genomics could be used to identify new anti-defense proteins, similar to what has been done very successfully for bacteria :ref{doi=10.1038/s41467-020-19415-3}. In general, recent studies have used a range of screening methods to identify new anti-defense proteins, and it is expected that many new anti-defense proteins will be described in the coming years.

## Anti-defense proteins target all stages of bacterial defenses

Most anti-defense proteins described to date directly bind a bacterial defense protein to block its activity. However, several other strategies have been described such as post-translational modification of a target, spatial segregation or signaling molecule degradation :ref{doi=10.3389/fmicb.2023.1211793}. They have been described to target all stages of bacterial defense.
Bacterial defenses can be separated into two broad categories: external and internal defenses.

### External defenses

Bacteria can hide receptors behind surface structures such as extracellular polysaccharides or capsular polysaccharides. Conversely, phages can produce various depolymerases to degrade the protective extracellular polysaccharides :ref{doi=10.1038/nrmicro3096}. 

### Internal defenses

Bacteria encode a variety of defense systems that prevent phage infection from progressing in various ways. Despite all this variability, all bacterial defense systems are schematically composed of three parts: a sensor recognizing the infection, an effector that achieves protection and a way to transmit the information between the sensor and the effector, either through signaling molecules or protein-protein interactions. Phage anti-defense proteins can target all three of these components.
- Sensor targeting:
	- Competitive binding to the sensor: an anti-DSR2 protein from phages phi3T and SPbeta can bind the bacterial DSR2 protein and prevent the physical interaction between DSR2 and its phage activator, the tail tube protein :ref{doi=10.1038/s41564-022-01207-8}. Moreover, Ocr protein from T7 can mimic a B-form DNA oligo and acts as a competitive inhibitor of bacterial type I restriction modification systems :ref{doi=10.1016/s1097-2765(02)00435-5}.
	- Masking the activator: some jumbo phages can produce a nucleus-like proteinaceous structure that hides phage DNA and replication machinery away from DNA-targeted systems such as type I CRISPR system :ref{doi=10.1038/s41564-019-0612-5}.

- Transmission targeting:
	- Degradation of signaling molecules: many systems rely on the production of a nucleotidic signaling molecule after phage sensing to activate the effector such as Pycsar, CBASS, and Thoeris systems. Phages possess proteins that can degrade these molecules to prevent effector activation, such as the anti-CBASS Acb1 from phage T4 and the anti-Pycsar Apyc1 from phage SBSphiJ :ref{doi=10.1038/s41586-022-04716-y}.
    - Sequestration of signaling molecules: an alternative strategy is to bind the signaling molecule very tightly without degrading it, which still prevents effector activation but is presumably easier to evolve than a catalysis-dependent degradation. These phage proteins are called sponges, and two were identified as anti-Thoeris: Tad1 from phage SBSphiJ7 and Tad2 from phage SPO1 and SPO1L3 :ref{doi=10.1038/s41586-022-05375-9,10.1038/s41586-023-06869-w}.

- Effector targeting:

	- Direct binding to block activity: Multiple anti-CRISPR proteins have been described that can directly bind all the different components of the Cas complex to prevent DNA degradation :ref{doi=10.3389/fmicb.2023.1211793,10.1146/annurev-genet-120417-031321}. So far, this is the most abundant category of anti-defense protein described, and it is not restricted to only anti-CRISPR proteins.
	- Antitoxin mimicking: toxin-antitoxin defense systems rely on a toxin effector and an antitoxin that will toxin-mediated toxicity in the absence of phage infection. Phages can hijack this process by mimicking the antitoxin to prevent toxin activity even during infection. For instance, phage ϕTE can produce a short repetitive RNA that mimics the ToxI RNA antitoxin of type III toxin-antitoxin system ToxIN and evades defense mediated by this system :ref{doi=10.1371/journal.pgen.1003023}.
